@@ -61,6 +61,10 @@ def split_with_num (s, n):
     """
     >>> [i for i in split_with_num ('123', 1)]
     ['1', '2', '3']
+    >>> [i for i in split_with_num ('123 adbc', 4)]
+    ['123 ', 'adbc']
+    >>> [i for i in split_with_num ('123 adbc', 3)]
+    ['123', ' ', 'adb', 'c']
     """
     while len(s) > n:
         pre = s[:n]
